/*---------------------------------------------------------------------------\
| Project:			Generic LV2 PIC18F458 CAN node firmware
|
| File:				exceptions.c
|
| Description:		Handles exceptions and error and other Bad Things
|
| Global Routines:	throwWarning()
|
| Local Routines:	None
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/


//------------------------------------------------------------------------
//  #includes
//------------------------------------------------------------------------

#include <p18f458.h>    // Register definitions for the PIC18F458
#include "project.h"	// Includes for the project (misc)
#include "excepts.h"	// Includes for exception handling

/*---------------------------------------------------------------------------\
| Function:		throwWarning
|
| Purpose:		Log the list of warnings.
|
| Discussion:	Put a list of errors in a circular buffer.
|
| Expects:		Nothing.
|
| Arguments:	WarningMessage: WARNING_MESSAGE type of warning message.
|
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Stolen from ADG code.
\---------------------------------------------------------------------------*/

void throwWarning (enum WARNING_MESSAGES warningMessage)
{
	static	uint8_t	warningMessageLog[128];
	static	uint8_t	index;

	// Log the message to a 256 byte array. Roll over the index to
	// zero and overwrite the log if we get too many messages.

	warningMessageLog[index] = warningMessage;
	++index;


}
