/*---------------------------------------------------------------------------\
| Project:	Generic LV2 PIC18F458 CAN node firmware
|
| File:		interrupts.h
|
| Descr.:	Includes for the serial.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _INTS_H	// Don't include more than once (last line = #endif)
#define _INTS_H

//------------------------------------------------------------------------
// Typedefs
//------------------------------------------------------------------------

enum INTERRUPT_TYPE
{
	LOW_PRIORITY_INT = 0,
	HIGH_PRIORITY_INT
};

//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------


//------------------------------------------------------------------------
// Global function declarations
//------------------------------------------------------------------------

void InitializeInterrupts (void);

void interrupt low_priority LowPriorityISR 	(void);
void interrupt 				HighPriorityISR	(void);


//------------------------------------------------------------------------
// #define'd function declarations (for easier reading)
//------------------------------------------------------------------------


#define	EnablePrioritizedInts()		(IPEN = 1)
#define	DisablePrioritizedInts()	(IPEN = 0)

#define	EnableHighPriorityInts()	(GIEH = 1)
#define	DisableHighPriorityInts()	(GIEH = 0)

#define EnableLowPriorityInts()		(GIEL = 1)
#define DisableLowPriorityInts()	(GIEL = 0)

#define Timer2PrioritySetting		TMR2IP
#define Timer2InterruptPending		TMR2IF
#define	Timer2InterruptEnabled		TMR2IE

#define	SerialTxPrioritySetting		TXIP
#define SerialTxInterruptPending	TXIF
#define SerialTxInterruptEnabled	TXIE

#define	SerialRxPrioritySetting		RCIP
#define SerialRxInterruptPending	RCIF
#define SerialRxInterruptEnabled	RCIE

#define CanTxb2PrioritySetting		TXB2IP
#define CanTxb2InterruptPending		TXB2IF
#define CanTxb2InterruptEnabled		TXB2IE

#define CanTxb1PrioritySetting		TXB1IP
#define CanTxb1InterruptPending		TXB1IF
#define CanTxb1InterruptEnabled		TXB1IE

#define CanTxb0PrioritySetting		TXB0IP
#define CanTxb0InterruptPending		TXB0IF
#define CanTxb0InterruptEnabled		TXB0IE

//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

// Choose whether an interupt is off, low priority or high priority.

#define	INTERRUPTOFF			0
#define	LOWPRIORITYINTERRUPT	1
#define	HIGHPRIORITYINTERRUPT	2

#define	CANTXB2INTPRIORITY		HIGHPRIORITYINTERRUPT
#define	CANTXB1INTPRIORITY		HIGHPRIORITYINTERRUPT
#define	CANTXB0INTPRIORITY		HIGHPRIORITYINTERRUPT

#define	TIMER2INTPRIORITY		HIGHPRIORITYINTERRUPT

#define	SERIALTXINTPRIORITY		LOWPRIORITYINTERRUPT
#define	SERIALRXINTPRIORITY		LOWPRIORITYINTERRUPT

// DON'T FORGET TO SET THE INTERRUPT PRIORITY BIT IN "InitializeInterrupts".

//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

// None


#endif			// _INTS_H
