/*---------------------------------------------------------------------------\
| Project:	Generic LV2 PIC18F458 CAN node firmware
|
| File:		serial.h
|
| Descr.:	Includes for the serial.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _SERIAL_H	// Don't include more than once (last line = #endif)
#define _SERIAL_H

//------------------------------------------------------------------------
// Typedefs, enums, etc.
//------------------------------------------------------------------------

enum SERIAL_INIT_MASK
{
	SERIAL_TRANSMIT_ENABLE				= 0b10000000,
	SERIAL_TRANSMIT_DISABLE				= 0b00000000,
	SERIAL_TRANSMIT_ENABLE_INTS			= 0b01000000,
	SERIAL_TRANSMIT_DISABLE_INTS		= 0b00000000,
	SERIAL_TRANSMIT_INTS_HIGHPRIORITY	= 0b00100000,
	SERIAL_TRANSMIT_INTS_LOWPRIORITY	= 0b00000000,

	SERIAL_RECEIVE_ENABLE				= 0b00010000,
	SERIAL_RECEIVE_DISABLE				= 0b00000000,
	SERIAL_RECEIVE_ENABLE_INTS			= 0b00001000,
	SERIAL_RECEIVE_DISABLE_INTS			= 0b00000000,
	SERIAL_RECEIVE_INTS_HIGHPRIORITY	= 0b00000100,
	SERIAL_RECEIVE_INTS_LOWPRIORITY		= 0b00000000,

	SERIAL_BITRATE_4800					= 0b00000000,
	SERIAL_BITRATE_9600					= 0b00000001,
	SERIAL_BITRATE_19200				= 0b00000010
};


//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------

// Define FIFO circular queues for serial port transmit and receive.
// NOTE THAT THESE NUMBERS ARE THE LENGTH IN BYTES (250 bytes) AND
// NOT THE FINAL INDEX NUMBER (249).

#define SERIALTXQUEUELENGTH 120
#define SERIALRXQUEUELENGTH 120




//------------------------------------------------------------------------
// Function declarations
//------------------------------------------------------------------------


void	InitializeSerial 	(enum SERIAL_INIT_MASK optionsMask);

void	SerialTxIsr			(void);
void	SerialRxIsr			(void);

void	SendSerialByte 		(UINT8 byte);
UINT8	GetSerialByte		(void);


// Writing to TXREG sends a byte out AND clears the interrupt

#define	TransmitAndClearInterupt(byte)	TXREG = byte


// Reading RCREG gets the current byte AND clears the interrupt:

#define	ReceiveAndClearInterrupt()	(RCREG)


// Enabled and disable TX interrupts and set priorities

#define DisableSerialTxInts()	PIE1bits.TXIE = 0
#define	EnableSerialTxInts()	PIE1bits.TXIE = 1

#define SetLPSerialTxInts()		IPR1bits.TXIP = 0
#define SetHPSerialTxInts()		IPR1bits.TXIP = 1


// Enabled and disable TX interrupts and set priorities

#define DisableSerialRxInts()	PIE1bits.RCIE = 0
#define	EnableSerialRxInts()	PIE1bits.RCIE = 1

#define SetLPSerialRxInts()		IPR1bits.RCIP = 0
#define SetHPSerialRxInts()		IPR1bits.RCIP = 1



//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

extern	BOOL gSerialRxDataAvailable;

#endif    			// _SERIAL_H





