/*---------------------------------------------------------------------------\
| 18F458 DEMO SOFTWARE
|
| File:					Timer2Module.c			All Timer2 Code
|
| Global Routines:		InitializeTimer2()
|						Timer2Isr()
|
| Local Routines:		None
|
| Discussion:        	Sure.
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 02/10/2002 | Created. Again.
\---------------------------------------------------------------------------*/


//------------------------------------------------------------------------
//  #includes and local #defines
//------------------------------------------------------------------------

#include <pic18.h>    	// Include for PICC-18
#include "pic18fxx8.h"	// Register definitions for the PIC18F458
#include "project.h"	// Includes for the project (misc)
#include "ints.h"		// Includes for interrupts
#include "timer2.h"		// Includes for the serial peripheral
#include "excepts.h"	// Includes for exception handling


//------------------------------------------------------------------------
//  Module-wide variables
//------------------------------------------------------------------------

bit gTimer2Flag;

/*---------------------------------------------------------------------------\
| Function:		InitializeTimer2
|
| Purpose:		Guess.
|
| Discussion:	Huh?
|
| Expects:		All interupts to be off (after all, we were just reset).
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 05/21/2002 | Created if you can call it that.
\---------------------------------------------------------------------------*/

void InitializeTimer2 (enum TIMER2_INIT_MASK optionsMask)
{

	// On reset, Timer2 is set to the following RESET values:
	//
	// T2CON = 0b00100101
	//			 ||||||||
	//			 |||||||+----------- T2CKPS0 = 00 = prescaler 1:1
	//			 ||||||+------------ T2CKPS1
	//			 |||||+------------- TMR2ON  = 0 = Timer2 off
	//			 ||||+-------------- TOUTPS0 = 0000 = postscaler 1:1
	//			 |||+--------------- TOUTPS1
	//			 ||+---------------- TOUTPS2
	//			 |+----------------- TOUTPS3
	//			 +------------------ <Unimplemented on PIC>
	//
	//	PR2 = 0xFF

	if (optionsMask & TIMER2_ENABLE)
	{
		switch (optionsMask & 0b00000011)
		{

			case TIMER2_250HZ:
				PR2 = 249; 				// ASSUMES FOSC = 20MHZ
				T2CON |= 0b00101110;	// ASSUMES FOSC = 20MHZ
				break;

			case TIMER2_500HZ:
				PR2 = 249; 				// ASSUMES FOSC = 20MHZ
				T2CON |= 0b01010101;	// ASSUMES FOSC = 20MHZ
				break;

			case TIMER2_1KHZ:
				PR2 = 249; 				// ASSUMES FOSC = 20MHZ
				T2CON |= 0b00101101;	// ASSUMES FOSC = 20MHZ
				break;

			case TIMER2_2KHZ:
				PR2 = 124; 				// ASSUMES FOSC = 20MHZ
				T2CON |= 0b00101101;	// ASSUMES FOSC = 20MHZ
				break;

			case TIMER2_2_5KHZ:
				PR2 = 24; 				// ASSUMES FOSC = 20MHZ
				T2CON |= 0b00101110;	// ASSUMES FOSC = 20MHZ
				break;

			case TIMER2_5KHZ:
				PR2 = 249; 				// ASSUMES FOSC = 20MHZ
				T2CON |= 0b00000101;	// ASSUMES FOSC = 20MHZ
				break;

			default:					// Default: 1KHz
				PR2 = 249; 				// ASSUMES FOSC = 20MHZ
				T2CON |= 0b00101101;	// ASSUMES FOSC = 20MHZ
				ThrowWarning(WARN_TIMER2_RATE);
				break;
		}

		if(optionsMask & TIMER2_ENABLE_INTS)
			EnableTimer2Ints();
		else
			DisableTimer2Ints();
	}
}





/*---------------------------------------------------------------------------\
| Function:		Timer2Isr
|
| Purpose:		Handle the Timer 2 interrupt
|
| Discussion:	Tell the rest of the code it has been one interrupt
|
| Expects:		-
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 02/10/2002 | Created if you can call it that.
\---------------------------------------------------------------------------*/

void Timer2Isr (void)
{
	static uint16_t counter;

	ClearTimer2Interrupt();

	/*
		EVENTUALLY: Check to see if the flag is still 1 and the mainline
		hasn't cleared it yet... that's a good intdication of something
		failing.
	*/

	// Let the rest of the world know about the interrupt

	// Hokey counter function to get a 2Hz Message.

	++counter;
	if (counter >= 500)
	{
		gTimer2Flag = 1;
		counter = 0;
	}
}


