/*---------------------------------------------------------------------------\
| Project:	Generic LV2 PIC18F458 CAN node firmware
|
| File:		timer2.h
|
| Descr.:	Includes for the stimer2.c module
|
|    Date    | Notes
|------------|------------------------------------------------------------
| 06/01/2002 | Created.
\---------------------------------------------------------------------------*/

#ifndef _TIMER2_H	// Don't include more than once (last line = #endif)
#define _TIMER2_H

//------------------------------------------------------------------------
// Typedefs, enums, etc.
//------------------------------------------------------------------------

enum TIMER2_INIT_MASK
{
	TIMER2_ENABLE				= 0b10000000,
	TIMER2_DISABLE				= 0b00000000,
	TIMER2_ENABLE_INTS			= 0b01000000,
	TIMER2_DISABLE_INTS			= 0b00000000,
	TIMER2_INTS_HIGHPRIORITY	= 0b00100000,
	TIMER2_INTS_LOWPRIORITY		= 0b00000000,

	TIMER2_250HZ				= 0b00000000,	// ** ASSUMES 20MHZ **
	TIMER2_500HZ				= 0b00000001,	// ** ASSUMES 20MHZ **
	TIMER2_1KHZ					= 0b00000010,	// ** ASSUMES 20MHZ **
	TIMER2_2KHZ					= 0b00000011,	// ** ASSUMES 20MHZ **
	TIMER2_2_5KHZ				= 0b00000100,	// ** ASSUMES 20MHZ **
	TIMER2_5KHZ					= 0b00000101,	// ** ASSUMES 20MHZ **
};


//------------------------------------------------------------------------
// #defines
//------------------------------------------------------------------------



//------------------------------------------------------------------------
// Function declarations
//------------------------------------------------------------------------


void	InitializeTimer2 	(enum TIMER2_INIT_MASK optionsMask);

void	Timer2Isr			(void);

// Clear the Timer2 interrupt flag

#define	ClearTimer2Interrupt()	PIR1bits.TMR2IF = 0


// Enabled and disable Timer2 interrupts and set priorities

#define DisableTimer2Ints()		PIE1bits.TMR2IE = 0
#define	EnableTimer2Ints()		PIE1bits.TMR2IE = 1

#define SetLPTimer2Ints()		IPR1bits.TMR2IP = 0
#define SetHPTimer2Ints()		IPR1bits.TMR2IP = 1



//------------------------------------------------------------------------
// Global variable declarations (extern)
//------------------------------------------------------------------------

extern	BOOL gTimer2Flag;

#endif    			// _TIMER2_H





